@@ -1124,12 +1124,9 @@ def set_ribbon(ctx, config, name):
     """
     res = _execute_sql(config.get_odoo_conn(), SQL, fetchone=True)
     if not (res and res[0] == "installed"):
-        try:
-            Commands.invoke(
-                ctx, "update", module=["web_environment_ribbon"], no_dangling_check=True
-            )
-        except Exception as ex:
-            print(ex)
+        Commands.invoke(
+            ctx, "update", module=["web_environment_ribbon"], no_dangling_check=True
+        )
 
     _execute_sql(
         config.get_odoo_conn(),
@@ -1248,6 +1245,8 @@ def make_dir_hashes(ctx, config, on_need):
     file_dirhashes = Path(customs_dir) / FILE_DIRHASHES
     if on_need and file_dirhashes.exists():
         return
+    
+    subprocess.check_call(["git", "clean", "-xdff"], cwd=customs_dir)
     hashes = subprocess.check_output(
         ["sha1deep", "-r", "-l", "-j", "5", customs_dir], encoding="utf8"
     ).strip()
